summaryrefslogtreecommitdiffstats
path: root/cmd-set-option.c
diff options
context:
space:
mode:
authornicm <nicm>2015-08-28 12:16:28 +0000
committernicm <nicm>2015-08-28 12:16:28 +0000
commit75d10058a41d8e95dda126d460a119a9037e9345 (patch)
tree86acff4bc6433f9e8f76c5d241a2e1c8833368eb /cmd-set-option.c
parent18d4802a7bcfc08948dccfd9084144b043ac591b (diff)
Run status update on a per-client timer at status-interval.
Diffstat (limited to 'cmd-set-option.c')
-rw-r--r--cmd-set-option.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/cmd-set-option.c b/cmd-set-option.c
index 761cee93..260961cb 100644
--- a/cmd-set-option.c
+++ b/cmd-set-option.c
@@ -176,7 +176,7 @@ cmd_set_option_exec(struct cmd *self, struct cmd_q *cmdq)
return (CMD_RETURN_ERROR);
}
/* Start or stop timers when automatic-rename changed. */
if (strcmp(oe->name, "automatic-rename") == 0) {
RB_FOREACH(w, windows, &windows) {
if (options_get_number(&w->options, "automatic-rename"))
@@ -185,6 +185,9 @@ cmd_set_option_exec(struct cmd *self, struct cmd_q *cmdq)
evtimer_del(&w->name_timer);
}
}
+ if (strcmp(oe->name, "status") == 0 ||
+ strcmp(oe->name, "status-interval") == 0)
+ status_timer_start_all();
/* Update sizes and redraw. May not need it but meh. */
recalculate_sizes();
@@ -176,7 +176,7 @@ cmd_set_option_exec(struct cmd *self, struct cmd_q *cmdq)
return (CMD_RETURN_ERROR);
}
- /* Start or stop timers when automatic-rename changed. */
+ /* Start or stop timers when name or status options changed. */
if (strcmp(oe->name, "automatic-rename") == 0) {
RB_FOREACH(w, windows, &windows) {